"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.configuration_cloud_express_api import ConfigurationCloudExpressApi  # noqa: E501


class TestConfigurationCloudExpressApi(unittest.TestCase):
    """ConfigurationCloudExpressApi unit test stubs"""

    def setUp(self):
        self.api = ConfigurationCloudExpressApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_apps(self):
        """Test case for add_apps

        """
        pass

    def test_add_cloudx_interfaces(self):
        """Test case for add_cloudx_interfaces

        """
        pass

    def test_add_cloudx_type(self):
        """Test case for add_cloudx_type

        """
        pass

    def test_delete_webex_prefix_lists(self):
        """Test case for delete_webex_prefix_lists

        """
        pass

    def test_edit_apps(self):
        """Test case for edit_apps

        """
        pass

    def test_enable_webex(self):
        """Test case for enable_webex

        """
        pass

    def test_enable_webex1(self):
        """Test case for enable_webex1

        """
        pass

    def test_get_apps(self):
        """Test case for get_apps

        """
        pass

    def test_get_attached_client_list(self):
        """Test case for get_attached_client_list

        """
        pass

    def test_get_attached_dia_list(self):
        """Test case for get_attached_dia_list

        """
        pass

    def test_get_attached_gateway_list(self):
        """Test case for get_attached_gateway_list

        """
        pass

    def test_get_cloud_x_available_apps(self):
        """Test case for get_cloud_x_available_apps

        """
        pass

    def test_get_cloud_x_status(self):
        """Test case for get_cloud_x_status

        """
        pass

    def test_get_dia_list(self):
        """Test case for get_dia_list

        """
        pass

    def test_get_gateway_list(self):
        """Test case for get_gateway_list

        """
        pass

    def test_get_site_list(self):
        """Test case for get_site_list

        """
        pass

    def test_site_per_app(self):
        """Test case for site_per_app

        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.colocation_service_chain_api import ColocationServiceChainApi  # noqa: E501


class TestColocationServiceChainApi(unittest.TestCase):
    """ColocationServiceChainApi unit test stubs"""

    def setUp(self):
        self.api = ColocationServiceChainApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_attach_service_chain(self):
        """Test case for attach_service_chain

        """
        pass

    def test_attach_service_chain1(self):
        """Test case for attach_service_chain1

        """
        pass

    def test_cancel_button(self):
        """Test case for cancel_button

        """
        pass

    def test_detach_service_chain(self):
        """Test case for detach_service_chain

        """
        pass

    def test_get_edge_devices(self):
        """Test case for get_edge_devices

        """
        pass

    def test_getpnf_devices(self):
        """Test case for getpnf_devices

        """
        pass


if __name__ == '__main__':
    unittest.main()




# flake8: noqa

# Import all APIs into this package.
# If you have many APIs here with many many models used in each API this may
# raise a `RecursionError`.
# In order to avoid this, import only the API that you directly need like:
#
#   from openapi_client.api.administration_audit_log_api import AdministrationAuditLogApi
#
# or import this package, but before doing it, use:
#
#   import sys
#   sys.setrecursionlimit(n)

# Import APIs into API package:
from openapi_client.api.administration_audit_log_api import AdministrationAuditLogApi
from openapi_client.api.administration_user_and_group_api import AdministrationUserAndGroupApi
from openapi_client.api.certificate_management_device_api import CertificateManagementDeviceApi
from openapi_client.api.certificate_management_v_manage_api import CertificateManagementVManageApi
from openapi_client.api.cluster_management_api import ClusterManagementApi
from openapi_client.api.colocation_cluster_api import ColocationClusterApi
from openapi_client.api.colocation_service_chain_api import ColocationServiceChainApi
from openapi_client.api.colocation_service_group_api import ColocationServiceGroupApi
from openapi_client.api.configuration_advanced_inspection_profile_definition_api import ConfigurationAdvancedInspectionProfileDefinitionApi
from openapi_client.api.configuration_azure_connect_api import ConfigurationAzureConnectApi
from openapi_client.api.configuration_circuits_api import ConfigurationCircuitsApi
from openapi_client.api.configuration_cloud_express_api import ConfigurationCloudExpressApi
from openapi_client.api.configuration_cloud_on_ramp_api import ConfigurationCloudOnRampApi
from openapi_client.api.configuration_configuration_group_api import ConfigurationConfigurationGroupApi
from openapi_client.api.configuration_dashboard_status_api import ConfigurationDashboardStatusApi
from openapi_client.api.configuration_device_actions_api import ConfigurationDeviceActionsApi
from openapi_client.api.configuration_device_config_history_api import ConfigurationDeviceConfigHistoryApi
from openapi_client.api.configuration_device_firmware_update_api import ConfigurationDeviceFirmwareUpdateApi
from openapi_client.api.configuration_device_inventory_api import ConfigurationDeviceInventoryApi
from openapi_client.api.configuration_device_ssl_proxy_certificate_management_api import ConfigurationDeviceSSLProxyCertificateManagementApi
from openapi_client.api.configuration_device_software_package_api import ConfigurationDeviceSoftwarePackageApi
from openapi_client.api.configuration_device_software_update_api import ConfigurationDeviceSoftwareUpdateApi
from openapi_client.api.configuration_device_template_api import ConfigurationDeviceTemplateApi
from openapi_client.api.configuration_disaster_recovery_api import ConfigurationDisasterRecoveryApi
from openapi_client.api.configuration_fqdn_list_builder_api import ConfigurationFQDNListBuilderApi
from openapi_client.api.configuration_feature_certificate_api import ConfigurationFeatureCertificateApi
from openapi_client.api.configuration_feature_profile_mobility_api import ConfigurationFeatureProfileMobilityApi
from openapi_client.api.configuration_feature_profile_sdwan_api import ConfigurationFeatureProfileSDWANApi
from openapi_client.api.configuration_general_template_api import ConfigurationGeneralTemplateApi
from openapi_client.api.configuration_multi_cloud_api import ConfigurationMultiCloudApi
from openapi_client.api.configuration_multidomain_policy_api import ConfigurationMultidomainPolicyApi
from openapi_client.api.configuration_network_design_api import ConfigurationNetworkDesignApi
from openapi_client.api.configuration_network_design_templates_api import ConfigurationNetworkDesignTemplatesApi
from openapi_client.api.configuration_policy_amp_definition_builder_api import ConfigurationPolicyAMPDefinitionBuilderApi
from openapi_client.api.configuration_policy_as_path_list_builder_api import ConfigurationPolicyASPathListBuilderApi
from openapi_client.api.configuration_policy_access_list_definition_builder_api import ConfigurationPolicyAccessListDefinitionBuilderApi
from openapi_client.api.configuration_policy_app_route_definition_builder_api import ConfigurationPolicyAppRouteDefinitionBuilderApi
from openapi_client.api.configuration_policy_app_probe_class_builder_api import ConfigurationPolicyAppProbeClassBuilderApi
from openapi_client.api.configuration_policy_application_list_builder_api import ConfigurationPolicyApplicationListBuilderApi
from openapi_client.api.configuration_policy_cflowd_definition_builder_api import ConfigurationPolicyCflowdDefinitionBuilderApi
from openapi_client.api.configuration_policy_cloud_application_builder_api import ConfigurationPolicyCloudApplicationBuilderApi
from openapi_client.api.configuration_policy_color_list_builder_api import ConfigurationPolicyColorListBuilderApi
from openapi_client.api.configuration_policy_community_list_builder_api import ConfigurationPolicyCommunityListBuilderApi
from openapi_client.api.configuration_policy_control_definition_builder_api import ConfigurationPolicyControlDefinitionBuilderApi
from openapi_client.api.configuration_policy_custom_application_builder_api import ConfigurationPolicyCustomApplicationBuilderApi
from openapi_client.api.configuration_policy_data_definition_builder_api import ConfigurationPolicyDataDefinitionBuilderApi
from openapi_client.api.configuration_policy_data_ipv6_prefix_list_builder_api import ConfigurationPolicyDataIPV6PrefixListBuilderApi
from openapi_client.api.configuration_policy_data_prefix_all_types_of_lists_builder_api import ConfigurationPolicyDataPrefixAllTypesOfListsBuilderApi
from openapi_client.api.configuration_policy_data_prefix_list_builder_api import ConfigurationPolicyDataPrefixListBuilderApi
from openapi_client.api.configuration_policy_data_prefix_and_fqdn_all_types_of_lists_builder_api import ConfigurationPolicyDataPrefixAndFQDNAllTypesOfListsBuilderApi
from openapi_client.api.configuration_policy_device_access_list_definition_builder_api import ConfigurationPolicyDeviceAccessListDefinitionBuilderApi
from openapi_client.api.configuration_policy_dial_peer_definition_builder_api import ConfigurationPolicyDialPeerDefinitionBuilderApi
from openapi_client.api.configuration_policy_expanded_community_list_builder_api import ConfigurationPolicyExpandedCommunityListBuilderApi
from openapi_client.api.configuration_policy_extended_community_list_builder_api import ConfigurationPolicyExtendedCommunityListBuilderApi
from openapi_client.api.configuration_policy_fxo_port_definition_builder_api import ConfigurationPolicyFXOPortDefinitionBuilderApi
from openapi_client.api.configuration_policy_fxsdid_port_definition_builder_api import ConfigurationPolicyFXSDIDPortDefinitionBuilderApi
from openapi_client.api.configuration_policy_fxs_port_definition_builder_api import ConfigurationPolicyFXSPortDefinitionBuilderApi
from openapi_client.api.configuration_policy_fax_protocol_list_builder_api import ConfigurationPolicyFaxProtocolListBuilderApi
from openapi_client.api.configuration_policy_forwarding_class_list_builder_api import ConfigurationPolicyForwardingClassListBuilderApi
from openapi_client.api.configuration_policy_geo_location_builder_api import ConfigurationPolicyGeoLocationBuilderApi
from openapi_client.api.configuration_policy_hub_and_spoke_definition_builder_api import ConfigurationPolicyHubAndSpokeDefinitionBuilderApi
from openapi_client.api.configuration_policy_ips_signature_list_builder_api import ConfigurationPolicyIPSSignatureListBuilderApi
from openapi_client.api.configuration_policy_ipv6_access_list_definition_builder_api import ConfigurationPolicyIPv6AccessListDefinitionBuilderApi
from openapi_client.api.configuration_policy_ipv6_device_access_list_definition_builder_api import ConfigurationPolicyIPv6DeviceAccessListDefinitionBuilderApi
from openapi_client.api.configuration_policy_ipv6_prefix_list_builder_api import ConfigurationPolicyIPv6PrefixListBuilderApi
from openapi_client.api.configuration_policy_intrusion_prevention_definition_builder_api import ConfigurationPolicyIntrusionPreventionDefinitionBuilderApi
from openapi_client.api.configuration_policy_list_builder_api import ConfigurationPolicyListBuilderApi
from openapi_client.api.configuration_policy_local_domain_definition_builder_api import ConfigurationPolicyLocalDomainDefinitionBuilderApi
from openapi_client.api.configuration_policy_local_domain_name_list_builder_api import ConfigurationPolicyLocalDomainNameListBuilderApi
from openapi_client.api.configuration_policy_media_profile_list_builder_api import ConfigurationPolicyMediaProfileListBuilderApi
from openapi_client.api.configuration_policy_mesh_definition_builder_api import ConfigurationPolicyMeshDefinitionBuilderApi
from openapi_client.api.configuration_policy_mirror_builder_api import ConfigurationPolicyMirrorBuilderApi
from openapi_client.api.configuration_policy_modem_passthrough_list_builder_api import ConfigurationPolicyModemPassthroughListBuilderApi
from openapi_client.api.configuration_policy_priisdn_port_definition_builder_api import ConfigurationPolicyPRIISDNPortDefinitionBuilderApi
from openapi_client.api.configuration_policy_policer_class_builder_api import ConfigurationPolicyPolicerClassBuilderApi
from openapi_client.api.configuration_policy_port_list_builder_api import ConfigurationPolicyPortListBuilderApi
from openapi_client.api.configuration_policy_prefix_list_builder_api import ConfigurationPolicyPrefixListBuilderApi
from openapi_client.api.configuration_policy_prefix_for_all_types_of_lists_builder_api import ConfigurationPolicyPrefixForAllTypesOfListsBuilderApi
from openapi_client.api.configuration_policy_protocol_name_list_builder_api import ConfigurationPolicyProtocolNameListBuilderApi
from openapi_client.api.configuration_policy_qos_map_definition_builder_api import ConfigurationPolicyQosMapDefinitionBuilderApi
from openapi_client.api.configuration_policy_region_list_builder_api import ConfigurationPolicyRegionListBuilderApi
from openapi_client.api.configuration_policy_rewrite_rule_definition_builder_api import ConfigurationPolicyRewriteRuleDefinitionBuilderApi
from openapi_client.api.configuration_policy_sla_class_builder_api import ConfigurationPolicySLAClassBuilderApi
from openapi_client.api.configuration_policy_secure_internet_gateway_data_centers_builder_api import ConfigurationPolicySecureInternetGatewayDataCentersBuilderApi
from openapi_client.api.configuration_policy_security_assembler_api import ConfigurationPolicySecurityAssemblerApi
from openapi_client.api.configuration_policy_site_list_builder_api import ConfigurationPolicySiteListBuilderApi
from openapi_client.api.configuration_policy_supervisory_disc_list_builder_api import ConfigurationPolicySupervisoryDiscListBuilderApi
from openapi_client.api.configuration_policy_tloc_list_builder_api import ConfigurationPolicyTLOCListBuilderApi
from openapi_client.api.configuration_policy_threat_grid_api_key_api import ConfigurationPolicyThreatGridApiKeyApi
from openapi_client.api.configuration_policy_translation_profile_list_builder_api import ConfigurationPolicyTranslationProfileListBuilderApi
from openapi_client.api.configuration_policy_translation_rules_list_builder_api import ConfigurationPolicyTranslationRulesListBuilderApi
from openapi_client.api.configuration_policy_trunk_group_list_builder_api import ConfigurationPolicyTrunkGroupListBuilderApi
from openapi_client.api.configuration_policy_url_black_list_builder_api import ConfigurationPolicyURLBlackListBuilderApi
from openapi_client.api.configuration_policy_url_filtering_definition_builder_api import ConfigurationPolicyURLFilteringDefinitionBuilderApi
from openapi_client.api.configuration_policy_url_white_list_builder_api import ConfigurationPolicyURLWhiteListBuilderApi
from openapi_client.api.configuration_policy_umbrella_data_builder_api import ConfigurationPolicyUmbrellaDataBuilderApi
from openapi_client.api.configuration_policy_vpn_list_builder_api import ConfigurationPolicyVPNListBuilderApi
from openapi_client.api.configuration_policy_vpn_membership_group_definition_builder_api import ConfigurationPolicyVPNMembershipGroupDefinitionBuilderApi
from openapi_client.api.configuration_policy_vpn_qos_map_definition_builder_api import ConfigurationPolicyVPNQosMapDefinitionBuilderApi
from openapi_client.api.configuration_policy_voice_assembler_api import ConfigurationPolicyVoiceAssemblerApi
from openapi_client.api.configuration_policy_zone_based_firewall_definition_builder_api import ConfigurationPolicyZoneBasedFirewallDefinitionBuilderApi
from openapi_client.api.configuration_policy_zone_list_builder_api import ConfigurationPolicyZoneListBuilderApi
from openapi_client.api.configuration_policy_v_edge_assembler_api import ConfigurationPolicyVEdgeAssemblerApi
from openapi_client.api.configuration_policy_v_edge_route_definition_builder_api import ConfigurationPolicyVEdgeRouteDefinitionBuilderApi
from openapi_client.api.configuration_policy_v_smart_assembler_api import ConfigurationPolicyVSmartAssemblerApi
from openapi_client.api.configuration_pre_upgrade_check_status_api import ConfigurationPreUpgradeCheckStatusApi
from openapi_client.api.configuration_quick_connect_api import ConfigurationQuickConnectApi
from openapi_client.api.configuration_rule_set_definition_api import ConfigurationRuleSetDefinitionApi
from openapi_client.api.configuration_ssl_decryption_policy_definition_builder_api import ConfigurationSSLDecryptionPolicyDefinitionBuilderApi
from openapi_client.api.configuration_ssl_decryption_utd_profile_definition_api import ConfigurationSSLDecryptionUTDProfileDefinitionApi
from openapi_client.api.configuration_secure_internet_gateway_tunnels_api import ConfigurationSecureInternetGatewayTunnelsApi
from openapi_client.api.configuration_security_group_definition_api import ConfigurationSecurityGroupDefinitionApi
from openapi_client.api.configuration_security_template_policy_api import ConfigurationSecurityTemplatePolicyApi
from openapi_client.api.configuration_segments_api import ConfigurationSegmentsApi
from openapi_client.api.configuration_settings_api import ConfigurationSettingsApi
from openapi_client.api.configuration_software_actions_api import ConfigurationSoftwareActionsApi
from openapi_client.api.configuration_template_configuration_api import ConfigurationTemplateConfigurationApi
from openapi_client.api.configuration_template_lock_api import ConfigurationTemplateLockApi
from openapi_client.api.configuration_template_master_api import ConfigurationTemplateMasterApi
from openapi_client.api.configuration_topology_api import ConfigurationTopologyApi
from openapi_client.api.configuration_voice_template_policy_api import ConfigurationVoiceTemplatePolicyApi
from openapi_client.api.configuration_v_edge_template_policy_api import ConfigurationVEdgeTemplatePolicyApi
from openapi_client.api.configuration_v_smart_template_policy_api import ConfigurationVSmartTemplatePolicyApi
from openapi_client.api.data_collection_agent_api import DataCollectionAgentApi
from openapi_client.api.deployment_mode_api import DeploymentModeApi
from openapi_client.api.device_messaging_api import DeviceMessagingApi
from openapi_client.api.device_network_api import DeviceNetworkApi
from openapi_client.api.locale_api import LocaleApi
from openapi_client.api.mdp_config_object_api import MDPConfigObjectApi
from openapi_client.api.mdp_device_sharing_api import MDPDeviceSharingApi
from openapi_client.api.mdp_internal_policy_management_api import MDPInternalPolicyManagementApi
from openapi_client.api.mdp_offboarding_api import MDPOffboardingApi
from openapi_client.api.mdp_onboarding_api import MDPOnboardingApi
from openapi_client.api.mdp_policy_management_api import MDPPolicyManagementApi
from openapi_client.api.msla_api import MSLAApi
from openapi_client.api.monitoring_art_api import MonitoringARTApi
from openapi_client.api.monitoring_alarms_details_api import MonitoringAlarmsDetailsApi
from openapi_client.api.monitoring_app_hosting_api import MonitoringAppHostingApi
from openapi_client.api.monitoring_app_hosting_interface_api import MonitoringAppHostingInterfaceApi
from openapi_client.api.monitoring_application_aware_routing_api import MonitoringApplicationAwareRoutingApi
from openapi_client.api.monitoring_application_aware_routing_statistics_api import MonitoringApplicationAwareRoutingStatisticsApi
from openapi_client.api.monitoring_bfd_api import MonitoringBFDApi
from openapi_client.api.monitoring_bridge_interface_api import MonitoringBridgeInterfaceApi
from openapi_client.api.monitoring_bridge_mac_api import MonitoringBridgeMacApi
from openapi_client.api.monitoring_cellular_eiolte_api import MonitoringCellularEIOLTEApi
from openapi_client.api.monitoring_cflowd_api import MonitoringCflowdApi
from openapi_client.api.monitoring_cflowd_flows_api import MonitoringCflowdFlowsApi
from openapi_client.api.monitoring_cloud_express_api import MonitoringCloudExpressApi
from openapi_client.api.monitoring_colocation_cluster_api import MonitoringColocationClusterApi
from openapi_client.api.monitoring_dpi_api import MonitoringDPIApi
from openapi_client.api.monitoring_dpion_demand_troubleshooting_api import MonitoringDPIOnDemandTroubleshootingApi
from openapi_client.api.monitoring_device_details_api import MonitoringDeviceDetailsApi
from openapi_client.api.monitoring_device_statistics_api import MonitoringDeviceStatisticsApi
from openapi_client.api.monitoring_device_statistics_details_api import MonitoringDeviceStatisticsDetailsApi
from openapi_client.api.monitoring_endpoint_tracker_status_api import MonitoringEndpointTrackerStatusApi
from openapi_client.api.monitoring_events_api import MonitoringEventsApi
from openapi_client.api.monitoring_flowlog_api import MonitoringFlowlogApi
from openapi_client.api.monitoring_health_api import MonitoringHealthApi
from openapi_client.api.monitoring_health_devices_api import MonitoringHealthDevicesApi
from openapi_client.api.monitoring_ips_alert_api import MonitoringIPsAlertApi
from openapi_client.api.monitoring_interface_statistics_api import MonitoringInterfaceStatisticsApi
from openapi_client.api.monitoring_qo_s_api import MonitoringQoSApi
from openapi_client.api.monitoring_security_unified_logging_connection_events_api import MonitoringSecurityUnifiedLoggingConnectionEventsApi
from openapi_client.api.monitoring_server_info_api import MonitoringServerInfoApi
from openapi_client.api.monitoring_service_chain_statistics_api import MonitoringServiceChainStatisticsApi
from openapi_client.api.monitoring_stats_download_api import MonitoringStatsDownloadApi
from openapi_client.api.monitoring_stats_processing_api import MonitoringStatsProcessingApi
from openapi_client.api.monitoring_status_api import MonitoringStatusApi
from openapi_client.api.monitoring_system_status_stats_api import MonitoringSystemStatusStatsApi
from openapi_client.api.monitoring_url_filtering_api import MonitoringURLFilteringApi
from openapi_client.api.monitoring_umbrella_api import MonitoringUmbrellaApi
from openapi_client.api.monitoring_umbrella_patterns_api import MonitoringUmbrellaPatternsApi
from openapi_client.api.monitoring_wlan_client_info_api import MonitoringWlanClientInfoApi
from openapi_client.api.multitenant_apis_provider_api import MultitenantAPIsProviderApi
from openapi_client.api.partner_aci_policy_builder_api import PartnerACIPolicyBuilderApi
from openapi_client.api.partner_dnacsdaapi_api import PartnerDNACSDAAPIApi
from openapi_client.api.partner_registration_api import PartnerRegistrationApi
from openapi_client.api.partner_wcm_configs_api import PartnerWCMConfigsApi
from openapi_client.api.real_time_monitoring_aaa_api import RealTimeMonitoringAAAApi
from openapi_client.api.real_time_monitoring_arp_api import RealTimeMonitoringARPApi
from openapi_client.api.real_time_monitoring_app_hosting_api import RealTimeMonitoringAppHostingApi
from openapi_client.api.real_time_monitoring_app_logs_api import RealTimeMonitoringAppLogsApi
from openapi_client.api.real_time_monitoring_application_aware_route_api import RealTimeMonitoringApplicationAwareRouteApi
from openapi_client.api.real_time_monitoring_appqoe_api import RealTimeMonitoringAppqoeApi
from openapi_client.api.real_time_monitoring_bfd_api import RealTimeMonitoringBFDApi
from openapi_client.api.real_time_monitoring_bgp_api import RealTimeMonitoringBGPApi
from openapi_client.api.real_time_monitoring_bridge_api import RealTimeMonitoringBridgeApi
from openapi_client.api.real_time_monitoring_cfm_api import RealTimeMonitoringCFMApi
from openapi_client.api.real_time_monitoring_cellular_api import RealTimeMonitoringCellularApi
from openapi_client.api.real_time_monitoring_cellular_aon_ipsec_interface_api import RealTimeMonitoringCellularAONIpsecInterfaceApi
from openapi_client.api.real_time_monitoring_cellular_eiolte_connection_service_api import RealTimeMonitoringCellularEIOLTEConnectionServiceApi
from openapi_client.api.real_time_monitoring_cellular_eiolte_hardware_service_api import RealTimeMonitoringCellularEIOLTEHardwareServiceApi
from openapi_client.api.real_time_monitoring_cellular_eiolte_network_service_api import RealTimeMonitoringCellularEIOLTENetworkServiceApi
from openapi_client.api.real_time_monitoring_cellular_eiolte_sim_service_api import RealTimeMonitoringCellularEIOLTESimServiceApi
from openapi_client.api.real_time_monitoring_cloud_express_api import RealTimeMonitoringCloudExpressApi
from openapi_client.api.real_time_monitoring_container_lifecycle_api import RealTimeMonitoringContainerLifecycleApi
from openapi_client.api.real_time_monitoring_crash_log_api import RealTimeMonitoringCrashLogApi
from openapi_client.api.real_time_monitoring_dhcp_api import RealTimeMonitoringDHCPApi
from openapi_client.api.real_time_monitoring_dot1x_api import RealTimeMonitoringDOT1xApi
from openapi_client.api.real_time_monitoring_dpi_api import RealTimeMonitoringDPIApi
from openapi_client.api.real_time_monitoring_dre_api import RealTimeMonitoringDREApi
from openapi_client.api.real_time_monitoring_device_api import RealTimeMonitoringDeviceApi
from openapi_client.api.real_time_monitoring_device_control_api import RealTimeMonitoringDeviceControlApi
from openapi_client.api.real_time_monitoring_device_feature_list_api import RealTimeMonitoringDeviceFeatureListApi
from openapi_client.api.real_time_monitoring_device_system_stats_api import RealTimeMonitoringDeviceSystemStatsApi
from openapi_client.api.real_time_monitoring_downloaded_images_api import RealTimeMonitoringDownloadedImagesApi
from openapi_client.api.real_time_monitoring_dual_static_route_tracker_service_api import RealTimeMonitoringDualStaticRouteTrackerServiceApi
from openapi_client.api.real_time_monitoring_eigrp_api import RealTimeMonitoringEIGRPApi
from openapi_client.api.real_time_monitoring_endpoint_tracker_group_service_api import RealTimeMonitoringEndpointTrackerGroupServiceApi
from openapi_client.api.real_time_monitoring_endpoint_tracker_service_api import RealTimeMonitoringEndpointTrackerServiceApi
from openapi_client.api.real_time_monitoring_geo_fencing_api import RealTimeMonitoringGeoFencingApi
from openapi_client.api.real_time_monitoring_hardware_api import RealTimeMonitoringHardwareApi
from openapi_client.api.real_time_monitoring_igmp_api import RealTimeMonitoringIGMPApi
from openapi_client.api.real_time_monitoring_ip_api import RealTimeMonitoringIPApi
from openapi_client.api.real_time_monitoring_i_psec_api import RealTimeMonitoringIPsecApi
from openapi_client.api.real_time_monitoring_ipv4_fib_api import RealTimeMonitoringIPv4FIBApi
from openapi_client.api.real_time_monitoring_ipv6_fib_api import RealTimeMonitoringIPv6FIBApi
from openapi_client.api.real_time_monitoring_ipv6_neighbours_api import RealTimeMonitoringIPv6NeighboursApi
from openapi_client.api.real_time_monitoring_interface_api import RealTimeMonitoringInterfaceApi
from openapi_client.api.real_time_monitoring_license_info_api import RealTimeMonitoringLicenseInfoApi
from openapi_client.api.real_time_monitoring_multicast_api import RealTimeMonitoringMulticastApi
from openapi_client.api.real_time_monitoring_nms_api import RealTimeMonitoringNMSApi
from openapi_client.api.real_time_monitoring_ntp_api import RealTimeMonitoringNTPApi
from openapi_client.api.real_time_monitoring_network_hub_resources_api import RealTimeMonitoringNetworkHubResourcesApi
from openapi_client.api.real_time_monitoring_omp_api import RealTimeMonitoringOMPApi
from openapi_client.api.real_time_monitoring_ospf_api import RealTimeMonitoringOSPFApi
from openapi_client.api.real_time_monitoring_orchestrator_api import RealTimeMonitoringOrchestratorApi
from openapi_client.api.real_time_monitoring_pim_api import RealTimeMonitoringPIMApi
from openapi_client.api.real_time_monitoring_pppo_e_api import RealTimeMonitoringPPPoEApi
from openapi_client.api.real_time_monitoring_policer_api import RealTimeMonitoringPolicerApi
from openapi_client.api.real_time_monitoring_policy_api import RealTimeMonitoringPolicyApi
from openapi_client.api.real_time_monitoring_rbac_api import RealTimeMonitoringRBACApi
from openapi_client.api.real_time_monitoring_reboot_history_api import RealTimeMonitoringRebootHistoryApi
from openapi_client.api.real_time_monitoring_sdwan_statistics_api import RealTimeMonitoringSDWANStatisticsApi
from openapi_client.api.real_time_monitoring_sfp_api import RealTimeMonitoringSFPApi
from openapi_client.api.real_time_monitoring_sig_api import RealTimeMonitoringSIGApi
from openapi_client.api.real_time_monitoring_security_api import RealTimeMonitoringSecurityApi
from openapi_client.api.real_time_monitoring_show_on_demand_local_api import RealTimeMonitoringShowOnDemandLocalApi
from openapi_client.api.real_time_monitoring_show_on_demand_remote_api import RealTimeMonitoringShowOnDemandRemoteApi
from openapi_client.api.real_time_monitoring_software_api import RealTimeMonitoringSoftwareApi
from openapi_client.api.real_time_monitoring_sslproxy_api import RealTimeMonitoringSslproxyApi
from openapi_client.api.real_time_monitoring_static_route_tracker_service_api import RealTimeMonitoringStaticRouteTrackerServiceApi
from openapi_client.api.real_time_monitoring_system_api import RealTimeMonitoringSystemApi
from openapi_client.api.real_time_monitoring_tcp_optimization_api import RealTimeMonitoringTCPOptimizationApi
from openapi_client.api.real_time_monitoring_tcpproxy_api import RealTimeMonitoringTcpproxyApi
from openapi_client.api.real_time_monitoring_transport_api import RealTimeMonitoringTransportApi
from openapi_client.api.real_time_monitoring_trustsec_api import RealTimeMonitoringTrustsecApi
from openapi_client.api.real_time_monitoring_tunnel_api import RealTimeMonitoringTunnelApi
from openapi_client.api.real_time_monitoring_utd_api import RealTimeMonitoringUTDApi
from openapi_client.api.real_time_monitoring_ucse_api import RealTimeMonitoringUcseApi
from openapi_client.api.real_time_monitoring_umbrella_api import RealTimeMonitoringUmbrellaApi
from openapi_client.api.real_time_monitoring_vdsl_service_api import RealTimeMonitoringVDSLServiceApi
from openapi_client.api.real_time_monitoring_vm_api import RealTimeMonitoringVMApi
from openapi_client.api.real_time_monitoring_vpn_api import RealTimeMonitoringVPNApi
from openapi_client.api.real_time_monitoring_vrrp_api import RealTimeMonitoringVRRPApi
from openapi_client.api.real_time_monitoring_voice_api import RealTimeMonitoringVoiceApi
from openapi_client.api.real_time_monitoring_wlan_api import RealTimeMonitoringWLANApi
from openapi_client.api.real_time_monitoring_wireless_api import RealTimeMonitoringWirelessApi
from openapi_client.api.resource_pool_api import ResourcePoolApi
from openapi_client.api.sdavc_cloud_connector_api import SDAVCCloudConnectorApi
from openapi_client.api.sdavc_domain_based_app_rules_api import SDAVCDomainBasedAppRulesApi
from openapi_client.api.sdavcip_address_based_app_rules_api import SDAVCIPAddressBasedAppRulesApi
from openapi_client.api.scheduled_backup_restore_api import ScheduledBackupRestoreApi
from openapi_client.api.smart_license_api import SmartLicenseApi
from openapi_client.api.system_cloud_service_api import SystemCloudServiceApi
from openapi_client.api.system_cloud_service_webex_api import SystemCloudServiceWebexApi
from openapi_client.api.system_container_api import SystemContainerApi
from openapi_client.api.system_reverse_proxy_api import SystemReverseProxyApi
from openapi_client.api.tag_api import TagApi
from openapi_client.api.tenant_backup_restore_api import TenantBackupRestoreApi
from openapi_client.api.tenant_management_api import TenantManagementApi
from openapi_client.api.tenant_migration_api import TenantMigrationApi
from openapi_client.api.troubleshooting_tools_device_connectivity_api import TroubleshootingToolsDeviceConnectivityApi
from openapi_client.api.troubleshooting_tools_device_group_api import TroubleshootingToolsDeviceGroupApi
from openapi_client.api.troubleshooting_tools_diagnostics_api import TroubleshootingToolsDiagnosticsApi
from openapi_client.api.umbrella_api import UmbrellaApi
from openapi_client.api.utility_configuration_db_api import UtilityConfigurationDBApi
from openapi_client.api.utility_logging_api import UtilityLoggingApi
from openapi_client.api.utility_security_api import UtilitySecurityApi
from openapi_client.api.workflow_management_api import WorkflowManagementApi
from openapi_client.api.default_api import DefaultApi



"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.configuration_device_inventory_api import ConfigurationDeviceInventoryApi  # noqa: E501


class TestConfigurationDeviceInventoryApi(unittest.TestCase):
    """ConfigurationDeviceInventoryApi unit test stubs"""

    def setUp(self):
        self.api = ConfigurationDeviceInventoryApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_check_self_signed_cert(self):
        """Test case for check_self_signed_cert

        """
        pass

    def test_claim_devices(self):
        """Test case for claim_devices

        """
        pass

    def test_create_device(self):
        """Test case for create_device

        """
        pass

    def test_decommission_vedge_cloud(self):
        """Test case for decommission_vedge_cloud

        """
        pass

    def test_delete_device(self):
        """Test case for delete_device

        """
        pass

    def test_devices_without_subject_sudi(self):
        """Test case for devices_without_subject_sudi

        """
        pass

    def test_edit_device(self):
        """Test case for edit_device

        """
        pass

    def test_form_post(self):
        """Test case for form_post

        """
        pass

    def test_generate_bootstrap_config_for_vedge(self):
        """Test case for generate_bootstrap_config_for_vedge

        """
        pass

    def test_generate_bootstrap_config_for_vedges(self):
        """Test case for generate_bootstrap_config_for_vedges

        """
        pass

    def test_generate_generic_bootstrap_config_for_vedges(self):
        """Test case for generate_generic_bootstrap_config_for_vedges

        """
        pass

    def test_get_all_unclaimed_devices(self):
        """Test case for get_all_unclaimed_devices

        """
        pass

    def test_get_bootstrap_config_zip(self):
        """Test case for get_bootstrap_config_zip

        """
        pass

    def test_get_cloud_dock_data_based_on_device_type(self):
        """Test case for get_cloud_dock_data_based_on_device_type

        """
        pass

    def test_get_cloud_dock_default_config_based_on_device_type(self):
        """Test case for get_cloud_dock_default_config_based_on_device_type

        """
        pass

    def test_get_controller_v_edge_sync_status(self):
        """Test case for get_controller_v_edge_sync_status

        """
        pass

    def test_get_devices_details(self):
        """Test case for get_devices_details

        """
        pass

    def test_get_management_system_ip_info(self):
        """Test case for get_management_system_ip_info

        """
        pass

    def test_get_rma_candidates(self):
        """Test case for get_rma_candidates

        """
        pass

    def test_get_root_cert_status_all(self):
        """Test case for get_root_cert_status_all

        """
        pass

    def test_get_tenant_management_system_ips(self):
        """Test case for get_tenant_management_system_ips

        """
        pass

    def test_invalidate_vmanage_root_ca(self):
        """Test case for invalidate_vmanage_root_ca

        """
        pass

    def test_migrate_device(self):
        """Test case for migrate_device

        """
        pass

    def test_reset_vedge_cloud(self):
        """Test case for reset_vedge_cloud

        """
        pass

    def test_set_life_cycle(self):
        """Test case for set_life_cycle

        """
        pass

    def test_sync_devices(self):
        """Test case for sync_devices

        """
        pass

    def test_sync_root_cert_chain(self):
        """Test case for sync_root_cert_chain

        """
        pass

    def test_update_device_subject_sudi(self):
        """Test case for update_device_subject_sudi

        """
        pass

    def test_validate_user(self):
        """Test case for validate_user

        """
        pass

    def test_validate_user1(self):
        """Test case for validate_user1

        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import openapi_client
from openapi_client.model.cellular import Cellular
from openapi_client.model.ethernet import Ethernet
from openapi_client.model.global_settings import GlobalSettings
from openapi_client.model.network_protocol import NetworkProtocol
from openapi_client.model.security_policy import SecurityPolicy
from openapi_client.model.variable import Variable
from openapi_client.model.vpn import Vpn
from openapi_client.model.wifi import Wifi
globals()['Cellular'] = Cellular
globals()['Ethernet'] = Ethernet
globals()['GlobalSettings'] = GlobalSettings
globals()['NetworkProtocol'] = NetworkProtocol
globals()['SecurityPolicy'] = SecurityPolicy
globals()['Variable'] = Variable
globals()['Vpn'] = Vpn
globals()['Wifi'] = Wifi
from openapi_client.model.profile_parcel import ProfileParcel


class TestProfileParcel(unittest.TestCase):
    """ProfileParcel unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testProfileParcel(self):
        """Test ProfileParcel"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ProfileParcel()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.real_time_monitoring_ipv6_neighbours_api import RealTimeMonitoringIPv6NeighboursApi  # noqa: E501


class TestRealTimeMonitoringIPv6NeighboursApi(unittest.TestCase):
    """RealTimeMonitoringIPv6NeighboursApi unit test stubs"""

    def setUp(self):
        self.api = RealTimeMonitoringIPv6NeighboursApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_ipv6_interface(self):
        """Test case for get_ipv6_interface

        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from openapi_client.api_client import ApiClient, Endpoint as _Endpoint
from openapi_client.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from openapi_client.model.get_o365_preferred_path_from_v_analytics_request import GetO365PreferredPathFromVAnalyticsRequest


class ConfigurationDeviceTemplateApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.attach_device_template_endpoint = _Endpoint(
            settings={
                'response_type': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                'auth': [],
                'endpoint_path': '/template/device/config/attachment',
                'operation_id': 'attach_device_template',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'body',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'body':
                        ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                },
                'attribute_map': {
                },
                'location_map': {
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.check_vbond_endpoint = _Endpoint(
            settings={
                'response_type': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                'auth': [],
                'endpoint_path': '/template/device/config/vbond',
                'operation_id': 'check_vbond',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.create_device_input_endpoint = _Endpoint(
            settings={
                'response_type': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                'auth': [],
                'endpoint_path': '/template/device/config/input',
                'operation_id': 'create_device_input',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'body',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'body':
                        ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                },
                'attribute_map': {
                },
                'location_map': {
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.create_input_without_device_endpoint = _Endpoint(
            settings={
                'response_type': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                'auth': [],
                'endpoint_path': '/template/device/config/exportcsv',
                'operation_id': 'create_input_without_device',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'body',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'body':
                        ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                },
                'attribute_map': {
                },
                'location_map': {
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.detach_device_template_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/template/device/config/detach',
                'operation_id': 'detach_device_template',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'body',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'body':
                        ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                },
                'attribute_map': {
                },
                'location_map': {
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.detach_sites_endpoint = _Endpoint(
            settings={
                'response_type': (str,),
                'auth': [],
                'endpoint_path': '/template/device/config/detachcloudx',
                'operation_id': 'detach_sites',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'body',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'body':
                        ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                },
                'attribute_map': {
                },
                'location_map': {
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.edit_cloudx_config_endpoint = _Endpoint(
            settings={
                'response_type': (str,),
                'auth': [],
                'endpoint_path': '/template/device/config/attachcloudx',
                'operation_id': 'edit_cloudx_config',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'body',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'body':
                        ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                },
                'attribute_map': {
                },
                'location_map': {
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.get_attached_config_to_device_endpoint = _Endpoint(
            settings={
                'response_type': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                'auth': [],
                'endpoint_path': '/template/device/config/attachedconfig',
                'operation_id': 'get_attached_config_to_device',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'device_id',
                    'policy_id',
                ],
                'required': [
                    'device_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'device_id':
                        (str,),
                    'policy_id':
                        (str,),
                },
                'attribute_map': {
                    'device_id': 'deviceId',
                    'policy_id': 'policyId',
                },
                'location_map': {
                    'device_id': 'query',
                    'policy_id': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_attached_device_list_endpoint = _Endpoint(
            settings={
                'response_type': ([{str: (bool, date, datetime, dict, float, int, list, str, none_type)}],),
                'auth': [],
                'endpoint_path': '/template/device/config/attached/{masterTemplateId}',
                'operation_id': 'get_attached_device_list',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'master_template_id',
                ],
                'required': [
                    'master_template_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'master_template_id':
                        (str,),
                },
                'attribute_map': {
                    'master_template_id': 'masterTemplateId',
                },
                'location_map': {
                    'master_template_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_device_configuration_preview_endpoint = _Endpoint(
            settings={
                'response_type': (str,),
                'auth': [],
                'endpoint_path': '/template/device/config/config',
                'operation_id': 'get_device_configuration_preview',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'body',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'body':
                        ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                },
                'attribute_map': {
                },
                'location_map': {
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'text/plain'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.get_device_list_by_master_template_id_endpoint = _Endpoint(
            settings={
                'response_type': ([{str: (bool, date, datetime, dict, float, int, list, str, none_type)}],),
                'auth': [],
                'endpoint_path': '/template/device/config/available/{masterTemplateId}',
                'operation_id': 'get_device_list_by_master_template_id',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'master_template_id',
                ],
                'required': [
                    'master_template_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'master_template_id':
                        (str,),
                },
                'attribute_map': {
                    'master_template_id': 'masterTemplateId',
                },
                'location_map': {
                    'master_template_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_devices_with_duplicate_ip_endpoint = _Endpoint(
            settings={
                'response_type': ([{str: (bool, date, datetime, dict, float, int, list, str, none_type)}],),
                'auth': [],
                'endpoint_path': '/template/device/config/duplicateip',
                'operation_id': 'get_devices_with_duplicate_ip',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'body',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'body':
                        ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                },
                'attribute_map': {
                },
                'location_map': {
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.get_quick_connect_variables_endpoint = _Endpoint(
            settings={
                'response_type': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                'auth': [],
                'endpoint_path': '/template/device/config/quickconnectvariable',
                'operation_id': 'get_quick_connect_variables',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'body',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'body':
                        ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                },
                'attribute_map': {
                },
                'location_map': {
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.process_input_comma_sep_file_endpoint = _Endpoint(
            settings={
                'response_type': (str,),
                'auth': [],
                'endpoint_path': '/template/device/config/process/input/file',
                'operation_id': 'process_input_comma_sep_file',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'multipart/form-data'
                ]
            },
            api_client=api_client
        )
        self.push_cli_template_endpoint = _Endpoint(
            settings={
                'response_type': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                'auth': [],
                'endpoint_path': '/template/device/config/attachcli',
                'operation_id': 'push_cli_template',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'body',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'body':
                        ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                },
                'attribute_map': {
                },
                'location_map': {
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.push_cloudx_config_endpoint = _Endpoint(
            settings={
                'response_type': (str,),
                'auth': [],
                'endpoint_path': '/template/device/config/attachcloudx',
                'operation_id': 'push_cloudx_config',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'body',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'body':
                        ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                },
                'attribute_map': {
                },
                'location_map': {
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.push_master_template_endpoint = _Endpoint(
            settings={
                'response_type': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                'auth': [],
                'endpoint_path': '/template/device/config/attachfeature',
                'operation_id': 'push_master_template',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'body',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'body':
                        ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                },
                'attribute_map': {
                },
                'location_map': {
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.push_master_template1_endpoint = _Endpoint(
            settings={
                'response_type': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                'auth': [],
                'endpoint_path': '/template/device/config/attachBootStrap',
                'operation_id': 'push_master_template1',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'body',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'body':
                        ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                },
                'attribute_map': {
                },
                'location_map': {
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.validate_template_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/template/device/config/verify',
                'operation_id': 'validate_template',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'get_o365_preferred_path_from_v_analytics_request',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'get_o365_preferred_path_from_v_analytics_request':
                        (GetO365PreferredPathFromVAnalyticsRequest,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'get_o365_preferred_path_from_v_analytics_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )

    def attach_device_template(
        self,
        **kwargs
    ):
        """attach_device_template  # noqa: E501

        Attach device template<br><br><br>Note: In a multitenant vManage system, this API is only available in the Provider view.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.attach_device_template(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            body ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}): Device template. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.attach_device_template_endpoint.call_with_http_info(**kwargs)

    def check_vbond(
        self,
        **kwargs
    ):
        """check_vbond  # noqa: E501

        Check if vBond is configured<br><br><br>Note: In a multitenant vManage system, this API is only available in the Provider view.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.check_vbond(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.check_vbond_endpoint.call_with_http_info(**kwargs)

    def create_device_input(
        self,
        **kwargs
    ):
        """create_device_input  # noqa: E501

        Create device input<br><br><br>Note: In a multitenant vManage system, this API is only available in the Provider view.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_device_input(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            body ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}): Template device input. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.create_device_input_endpoint.call_with_http_info(**kwargs)

    def create_input_without_device(
        self,
        **kwargs
    ):
        """create_input_without_device  # noqa: E501

        Export the device template to CSV format for given template id<br><br><br>Note: In a multitenant vManage system, this API is only available in the Provider view.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_input_without_device(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            body ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}): Device template. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.create_input_without_device_endpoint.call_with_http_info(**kwargs)

    def detach_device_template(
        self,
        **kwargs
    ):
        """detach_device_template  # noqa: E501

        Detach device template<br><br><br>Note: In a multitenant vManage system, this API is only available in the Provider view.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.detach_device_template(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            body ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}): Device template. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.detach_device_template_endpoint.call_with_http_info(**kwargs)

    def detach_sites(
        self,
        **kwargs
    ):
        """detach_sites  # noqa: E501

        Disable enabled gateways, clients, dias<br><br><br>Note: In a multitenant vManage system, this API is only available in the Provider view.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.detach_sites(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            body ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}): CloudX config. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            str
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.detach_sites_endpoint.call_with_http_info(**kwargs)

    def edit_cloudx_config(
        self,
        **kwargs
    ):
        """edit_cloudx_config  # noqa: E501

        Edit already enabled gateways, clients, dias<br><br><br>Note: In a multitenant vManage system, this API is only available in the Provider view.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.edit_cloudx_config(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            body ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}): CloudX config. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            str
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.edit_cloudx_config_endpoint.call_with_http_info(**kwargs)

    def get_attached_config_to_device(
        self,
        device_id,
        **kwargs
    ):
        """get_attached_config_to_device  # noqa: E501

        Get attached config to device<br><br><br>Note: In a multitenant vManage system, this API is only available in the Provider view.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_attached_config_to_device(device_id, async_req=True)
        >>> result = thread.get()

        Args:
            device_id (str): Device Model ID

        Keyword Args:
            policy_id (str): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['device_id'] = \
            device_id
        return self.get_attached_config_to_device_endpoint.call_with_http_info(**kwargs)

    def get_attached_device_list(
        self,
        master_template_id,
        **kwargs
    ):
        """get_attached_device_list  # noqa: E501

        Get attached device list by master template Id<br><br><br>Note: In a multitenant vManage system, this API is only available in the Provider view.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_attached_device_list(master_template_id, async_req=True)
        >>> result = thread.get()

        Args:
            master_template_id (str): Template Id

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            [{str: (bool, date, datetime, dict, float, int, list, str, none_type)}]
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['master_template_id'] = \
            master_template_id
        return self.get_attached_device_list_endpoint.call_with_http_info(**kwargs)

    def get_device_configuration_preview(
        self,
        **kwargs
    ):
        """get_device_configuration_preview  # noqa: E501

        Get device configuration<br><br><br>Note: In a multitenant vManage system, this API is only available in the Provider view.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_device_configuration_preview(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            body ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}): Device template. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            str
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.get_device_configuration_preview_endpoint.call_with_http_info(**kwargs)

    def get_device_list_by_master_template_id(
        self,
        master_template_id,
        **kwargs
    ):
        """get_device_list_by_master_template_id  # noqa: E501

        Get possible device list by master template Id<br><br><br>Note: In a multitenant vManage system, this API is only available in the Provider view.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_device_list_by_master_template_id(master_template_id, async_req=True)
        >>> result = thread.get()

        Args:
            master_template_id (str): Template Id

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            [{str: (bool, date, datetime, dict, float, int, list, str, none_type)}]
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['master_template_id'] = \
            master_template_id
        return self.get_device_list_by_master_template_id_endpoint.call_with_http_info(**kwargs)

    def get_devices_with_duplicate_ip(
        self,
        **kwargs
    ):
        """get_devices_with_duplicate_ip  # noqa: E501

        Detects duplicate system IP from a list of devices<br><br><br>Note: In a multitenant vManage system, this API is only available in the Provider view.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_devices_with_duplicate_ip(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            body ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}): Device list. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            [{str: (bool, date, datetime, dict, float, int, list, str, none_type)}]
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.get_devices_with_duplicate_ip_endpoint.call_with_http_info(**kwargs)

    def get_quick_connect_variables(
        self,
        **kwargs
    ):
        """get_quick_connect_variables  # noqa: E501

        Get connection variables to be configured  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_quick_connect_variables(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            body ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}): Device List. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.get_quick_connect_variables_endpoint.call_with_http_info(**kwargs)

    def process_input_comma_sep_file(
        self,
        **kwargs
    ):
        """process_input_comma_sep_file  # noqa: E501

        Process input comma separated file<br><br><br>Note: In a multitenant vManage system, this API is only available in the Provider view.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.process_input_comma_sep_file(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            str
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.process_input_comma_sep_file_endpoint.call_with_http_info(**kwargs)

    def push_cli_template(
        self,
        **kwargs
    ):
        """push_cli_template  # noqa: E501

        Attach CLI device template<br><br><br>Note: In a multitenant vManage system, this API is only available in the Provider view.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.push_cli_template(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            body ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}): Device template. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.push_cli_template_endpoint.call_with_http_info(**kwargs)

    def push_cloudx_config(
        self,
        **kwargs
    ):
        """push_cloudx_config  # noqa: E501

        Enable gateways, clients, dias  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.push_cloudx_config(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            body ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}): CloudX config. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            str
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.push_cloudx_config_endpoint.call_with_http_info(**kwargs)

    def push_master_template(
        self,
        **kwargs
    ):
        """push_master_template  # noqa: E501

        Attach feature device template<br><br><br>Note: In a multitenant vManage system, this API is only available in the Provider view.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.push_master_template(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            body ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}): Device template. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.push_master_template_endpoint.call_with_http_info(**kwargs)

    def push_master_template1(
        self,
        **kwargs
    ):
        """push_master_template1  # noqa: E501

        Attach feature device template<br><br><br>Note: In a multitenant vManage system, this API is only available in the Provider view.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.push_master_template1(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            body ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}): Device template. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.push_master_template1_endpoint.call_with_http_info(**kwargs)

    def validate_template(
        self,
        **kwargs
    ):
        """validate_template  # noqa: E501

        Validate full template\" <br><br><br>Note: In a multitenant vManage system, this API is only available in the Provider view.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.validate_template(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            get_o365_preferred_path_from_v_analytics_request (GetO365PreferredPathFromVAnalyticsRequest): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.validate_template_endpoint.call_with_http_info(**kwargs)

